"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLocalImageFileUrl = createLocalImageFileUrl;
exports.createEmbeddedImageUrl = createEmbeddedImageUrl;
exports.createRemoteImageUrl = createRemoteImageUrl;
const path = __importStar(require("path"));
const plantUmlEncoder = __importStar(require("plantuml-encoder"));
/**
 * Creates a URL to a local image file.
 * @param pageFilePath Path of the page that is referencing the image.
 * @param imageFilePath Path to the local image file.
 * @returns The URL to the local image file.
 */
function createLocalImageFileUrl(pageFilePath, imageFilePath) {
    const pageFileDir = path.dirname(pageFilePath);
    return path.relative(pageFileDir, imageFilePath);
}
/**
 * Creates a URL for an embedded image.
 * @param imageData The data of the image.
 * @param imageFormat The format of the image data.
 * @returns The URL for the embedded image.
 */
function createEmbeddedImageUrl(imageData, imageFormat) {
    const mimeType = imageFormat === "png" ? "image/png" : "image/svg+xml";
    return "data:" + mimeType + ";base64," + imageData.toString("base64");
}
/**
 * Creates a remote server URL that generates an image.
 * @param baseUrl The base URL for the image URL.
 * @param plantUmlCode The PlantUML code for the image.
 * @param imageFormat The format for the image.
 * @returns The remote server URL for the image.
 */
function createRemoteImageUrl(baseUrl, plantUmlCode, imageFormat) {
    const encodedPlantUml = plantUmlEncoder.encode(plantUmlCode);
    return baseUrl + "/plantuml/" + imageFormat + "/" + encodedPlantUml;
}
